@@ -1,28 +1,22 @@
-# encoding: utf-8
-
 """
 .. codeauthor:: Tsuyoshi Hombashi <tsuyoshi.hombashi@gmail.com>
 """
 
-from __future__ import absolute_import, unicode_literals
-
 import contextlib
 import errno
 import os
 import re
 import sys
 
-import logbook
-import logbook.more
 import msgfy
 import subprocrunner as spr
 import typepy
+from humanreadable import ParameterError
 from path import Path
 from simplesqlite import SimpleSQLite
 
 from ._const import IPV6_OPTION_ERROR_MSG_FORMAT, TcCommandOutput
-from ._error import ParameterError
-from ._logger import logger
+from ._logger import logger, set_log_level
 
 
 _bin_path_cache = {}
@@ -48,9 +42,9 @@ def find_bin_path(command):
     if command in _bin_path_cache:
         return _bin_path_cache.get(command)
 
-    bin_path = spr.Which(command)
+    bin_path = spr.Which(command, follow_symlinks=True)
     if bin_path.is_exist():
-        _bin_path_cache[command] = _to_regular_bin_path(bin_path.abspath())
+        _bin_path_cache[command] = bin_path.abspath()
         return _bin_path_cache[command]
 
     for sbin_path in ("/sbin/{:s}".format(command), "/usr/sbin/{:s}".format(command)):
@@ -58,7 +52,8 @@ def find_bin_path(command):
             _bin_path_cache[command] = _to_regular_bin_path(sbin_path)
             return _bin_path_cache[command]
 
-    return None
+    # return the command as it is when binary file not found
+    return command
 
 
 def check_command_installation(command):
@@ -70,25 +65,8 @@ def check_command_installation(command):
 
 
 def initialize_cli(options):
-    from ._logger import set_log_level
-
-    debug_level_format_str = (
-        "[{record.level_name}] {record.channel} {record.func_name} "
-        "({record.lineno}): {record.message}"
-    )
-    if options.log_level == logbook.DEBUG:
-        info_level_format_str = debug_level_format_str
-    else:
-        info_level_format_str = "[{record.level_name}] {record.channel}: {record.message}"
-
-    logbook.more.ColorizedStderrHandler(
-        level=logbook.DEBUG, format_string=debug_level_format_str
-    ).push_application()
-    logbook.more.ColorizedStderrHandler(
-        level=logbook.INFO, format_string=info_level_format_str
-    ).push_application()
-
     set_log_level(options.log_level)
+
     spr.SubprocessRunner.is_save_history = True
 
     if options.is_output_stacktrace:
@@ -140,36 +118,41 @@ def normalize_tc_value(tc_obj):
         sys.exit(errno.EINVAL)
 
 
-def run_command_helper(command, ignore_error_msg_regexp, notice_msg, exception_class=None):
-    proc = spr.SubprocessRunner(command, error_log_level=logbook.NOTSET)
-    proc.run()
+def run_command_helper(
+    command, ignore_error_msg_regexp, notice_msg, msg_log_level="WARNING", exception_class=None
+):
+    runner = spr.SubprocessRunner(command, error_log_level="QUIET")
+    runner.run()
 
-    if proc.returncode == 0:
+    returncode = runner.returncode
+    if returncode == 0:
         return 0
 
     if ignore_error_msg_regexp:
-        match = ignore_error_msg_regexp.search(proc.stderr)
-        if match is None:
+        if ignore_error_msg_regexp.search(runner.stderr) is None:
             error_msg = "\n".join(
                 [
                     "command execution failed",
                     "  command={}".format(command),
-                    "  stderr={}".format(proc.stderr),
+                    "  stderr={}".format(runner.stderr),
                 ]
             )
 
-            if re.search("RTNETLINK answers: Operation not permitted", proc.stderr):
+            if re.search("RTNETLINK answers: Operation not permitted", runner.stderr):
                 logger.error(error_msg)
-                sys.exit(proc.returncode)
+                sys.exit(returncode)
 
             logger.error(error_msg)
 
-            return proc.returncode
+            return returncode
+        else:
+            # ignorable error occurred
+            returncode = 0
 
     if typepy.is_not_null_string(notice_msg):
-        logger.notice(notice_msg)
+        logger.log(msg_log_level, notice_msg)
 
     if exception_class is not None:
         raise exception_class(command)
 
-    return proc.returncode
+    return returncode
