@@ -1,27 +1,28 @@
-# encoding: utf-8
-
 """
 .. codeauthor:: Tsuyoshi Hombashi <tsuyoshi.hombashi@gmail.com>
 """
 
-from __future__ import absolute_import, unicode_literals
-
 import re
 
-import simplejson as json
 import typepy
 
-from ._interface import AbstractParser
 from .._const import ShapingAlgorithm, Tc, TcSubCommand
 from .._logger import logger
+from ._interface import AbstractParser
+
+
+try:
+    import ujson as json
+except ImportError:
+    import json  # type: ignore
 
 
 class TcClassParser(AbstractParser):
-    class Pattern(object):
+    class Pattern:
         CLASS_ID = "[0-9a-z:]+"
         RATE = "[0-9]+[KMGT]?"
 
-    class Key(object):
+    class Key:
         DEVICE = Tc.Param.DEVICE
         CLASS_ID = Tc.Param.CLASS_ID
         RATE = "rate"
@@ -32,11 +33,6 @@ class TcClassParser(AbstractParser):
     def _tc_subcommand(self):
         return TcSubCommand.CLASS.value
 
-    def __init__(self, con):
-        super(TcClassParser, self).__init__()
-
-        self.__con = con
-
     def parse(self, device, text):
         entry_list = []
 
@@ -56,7 +52,7 @@ class TcClassParser(AbstractParser):
             entry_list.append(self.__parsed_param)
 
         if entry_list:
-            self.__con.create_table_from_data_matrix(self._tc_subcommand, self.Key.LIST, entry_list)
+            self._con.create_table_from_data_matrix(self._tc_subcommand, self.Key.LIST, entry_list)
 
         logger.debug(
             "tc {:s} parse result: {}".format(self._tc_subcommand, json.dumps(entry_list, indent=4))
