@@ -1,28 +1,25 @@
-# encoding: utf-8
-
 """
 .. codeauthor:: Tsuyoshi Hombashi <tsuyoshi.hombashi@gmail.com>
 """
 
-from __future__ import absolute_import, unicode_literals
-
 import abc
 
-import six
 
-
-@six.add_metaclass(abc.ABCMeta)
-class ParserInterface(object):
+class ParserInterface(metaclass=abc.ABCMeta):
     @abc.abstractmethod
     def parse(self, device, text):  # pragma: no cover
         pass
 
 
-@six.add_metaclass(abc.ABCMeta)
-class AbstractParser(ParserInterface):
-    def __init__(self):
+class AbstractParser(ParserInterface, metaclass=abc.ABCMeta):
+    def __init__(self, con):
+        self._con = con
         self._clear()
 
+    @property
+    def con(self):
+        return self._con
+
     @abc.abstractproperty
     def _tc_subcommand(self):  # pragma: no cover
         pass
