@@ -1,34 +1,33 @@
-#!/usr/bin/env python
-# encoding: utf-8
+#!/usr/bin/env python3
 
 """
 .. codeauthor:: Tsuyoshi Hombashi <tsuyoshi.hombashi@gmail.com>
 """
 
-from __future__ import absolute_import, print_function, unicode_literals
 
 import errno
 import ipaddress
 import sys
 
-import logbook
+import humanreadable as hr
 import msgfy
 import subprocrunner as spr
+from loguru import logger
 
 from .__version__ import __version__
 from ._argparse_wrapper import ArgparseWrapper
 from ._capabilities import check_execution_authority
 from ._common import initialize_cli, is_execute_tc_command, normalize_tc_value
-from ._const import IPV6_OPTION_ERROR_MSG_FORMAT, ShapingAlgorithm, Tc, TrafficDirection
-from ._converter import HumanReadableTime
-from ._error import (
-    ContainerNotFoundError,
-    ModuleNotFoundError,
-    NetworkInterfaceNotFoundError,
-    ParameterError,
+from ._const import (
+    DELAY_DISTRIBUTIONS,
+    IPV6_OPTION_ERROR_MSG_FORMAT,
+    ShapingAlgorithm,
+    Tc,
+    TrafficDirection,
 )
+from ._error import ContainerNotFoundError, ModuleNotFoundError, NetworkInterfaceNotFoundError
 from ._importer import set_tc_from_file
-from ._logger import logger, set_log_level
+from ._logger import set_log_level
 from ._main import Main
 from ._netem_param import (
     MAX_CORRUPTION_RATE,
@@ -45,10 +44,14 @@ from ._shaping_rule_finder import TcShapingRuleFinder
 from .traffic_control import TrafficControl
 
 
+def _get_unit_help_msg():
+    return ", ".join(["/".join(values) for values in hr.Time.get_text_units().values()])
+
+
 def get_arg_parser():
     parser = ArgparseWrapper(__version__)
 
-    if set(["-d", "--device"]).intersection(set(sys.argv)):
+    if {"-d", "--device"}.intersection(set(sys.argv)):
         # deprecated: remain for backward compatibility
         parser.parser.add_argument(
             "-d", "--device", required=True, help="network device name (e.g. eth0)"
@@ -98,13 +101,15 @@ def get_arg_parser():
         dest="bandwidth_rate",
         help="""network bandwidth rate [bit per second].
         the minimum bandwidth rate is 8 bps.
-        valid units are either: K/M/G/Kbps/Mbps/Gbps.
+        valid units are either: {}.
         e.g. tcset eth0 --rate 10Mbps
-        """,
+        """.format(
+            ", ".join([", ".join(values) for values in hr.BitPerSecond.get_text_units().values()])
+        ),
     )
     group.add_argument(
         "--delay",
-        dest="network_latency",
+        dest="latency_time",
         default=Tc.ValueRange.LatencyTime.MIN,
         help="""round trip network delay. the valid range is from {min_value:} to {max_value:}.
         valid time units are: {unit}. if no unit string found, considered milliseconds as
@@ -112,7 +117,7 @@ def get_arg_parser():
         """.format(
             min_value=Tc.ValueRange.LatencyTime.MIN,
             max_value=Tc.ValueRange.LatencyTime.MAX,
-            unit="/".join(HumanReadableTime.get_valid_units()),
+            unit=_get_unit_help_msg(),
         ),
     )
     group.add_argument(
@@ -124,9 +129,18 @@ def get_arg_parser():
         network latency distribution is uniform, without this option. valid time units are: {unit}.
         if no unit string found, considered milliseconds as the time unit.
         """.format(
-            unit="/".join(HumanReadableTime.get_valid_units())
+            unit=_get_unit_help_msg()
         ),
     )
+    group.add_argument(
+        "--delay-distribution",
+        dest="latency_distribution",
+        choices=DELAY_DISTRIBUTIONS,
+        default=DELAY_DISTRIBUTIONS[0],
+        help="""choose the delay distribution. (default=%(default)s)",
+        [limitation] this parameter can not be shown by tcshow, and export/import as config.
+        """,
+    )
     group.add_argument(
         "--loss",
         dest="packet_loss_rate",
@@ -236,11 +250,11 @@ class TcSetMain(Main):
             normalize_tc_value(tc)
 
             if self._options.overwrite:
-                if self._options.log_level == logbook.INFO:
-                    set_log_level(logbook.ERROR)
+                if self._options.log_level == "INFO":
+                    set_log_level("ERROR")
 
                 try:
-                    tc.delete_all_tc()
+                    tc.delete_all_rules()
                 except NetworkInterfaceNotFoundError:
                     pass
 
@@ -265,7 +279,7 @@ class TcSetMain(Main):
                 return errno.EINVAL
 
             try:
-                return_code_list.append(tc.set_tc())
+                return_code_list.append(tc.set_shaping_rule())
             except NetworkInterfaceNotFoundError as e:
                 logger.error(e)
                 return errno.EINVAL
@@ -283,7 +297,7 @@ class TcSetMain(Main):
         except ipaddress.AddressValueError as e:
             logger.error(IPV6_OPTION_ERROR_MSG_FORMAT.format(e))
             return errno.EINVAL
-        except ParameterError as e:
+        except hr.ParameterError as e:
             logger.error(msgfy.to_error_message(e))
             return errno.EINVAL
 
@@ -298,8 +312,9 @@ class TcSetMain(Main):
             netem_param=NetemParameter(
                 device=device,
                 bandwidth_rate=options.bandwidth_rate,
-                latency_time=options.network_latency,
+                latency_time=options.latency_time,
                 latency_distro_time=options.latency_distro_time,
+                latency_distribution=options.latency_distribution,
                 packet_loss_rate=options.packet_loss_rate,
                 packet_duplicate_rate=options.packet_duplicate_rate,
                 corruption_rate=options.corruption_rate,
@@ -333,7 +348,8 @@ def main():
         if options.direction == TrafficDirection.INCOMING:
             check_execution_authority("ip")
     else:
-        spr.SubprocessRunner.default_is_dry_run = True
+        if not options.import_setting:
+            spr.SubprocessRunner.default_is_dry_run = True
 
     try:
         verify_netem_module()
@@ -341,7 +357,9 @@ def main():
         logger.debug(e)
 
     if options.import_setting:
-        return set_tc_from_file(logger, options.device, options.overwrite)
+        return set_tc_from_file(
+            logger, options.device, options.overwrite, options.tc_command_output
+        )
 
     spr.SubprocessRunner.clear_history()
 
