@@ -1,20 +1,23 @@
-# encoding: utf-8
-
 """
 .. codeauthor:: Tsuyoshi Hombashi <tsuyoshi.hombashi@gmail.com>
 """
 
-from __future__ import absolute_import, division
 
 import errno
 import re
 
 import msgfy
-import six
 import subprocrunner as spr
 import typepy
+from humanreadable import ParameterError
 
-from ._common import find_bin_path, logging_context, run_command_helper, validate_within_min_max
+from ._common import (
+    find_bin_path,
+    is_execute_tc_command,
+    logging_context,
+    run_command_helper,
+    validate_within_min_max,
+)
 from ._const import (
     LIST_MANGLE_TABLE_OPTION,
     ShapingAlgorithm,
@@ -23,7 +26,7 @@ from ._const import (
     TcSubCommand,
     TrafficDirection,
 )
-from ._error import NetworkInterfaceNotFoundError, ParameterError
+from ._error import NetworkInterfaceNotFoundError
 from ._iptables import IptablesMangleController, get_iptables_base_command
 from ._logger import logger
 from ._network import sanitize_network, verify_network_interface
@@ -33,7 +36,7 @@ from .shaper.htb import HtbShaper
 from .shaper.tbf import TbfShaper
 
 
-class TrafficControl(object):
+class TrafficControl:
     __MIN_PORT = 0
     __MAX_PORT = 65535
 
@@ -156,7 +159,7 @@ class TrafficControl(object):
         is_ipv6=False,
         is_change_shaping_rule=False,
         is_add_shaping_rule=False,
-        is_enable_iptables=True,
+        is_enable_iptables=False,
         shaping_algorithm=None,
         tc_command_output=TcCommandOutput.NOT_SET,
     ):
@@ -257,7 +260,7 @@ class TrafficControl(object):
     def make_srcdst_text(self):
         return "".join(
             [
-                six.text_type(item)
+                str(item)
                 for item in [
                     self.dst_network,
                     self.exclude_dst_network,
@@ -271,7 +274,7 @@ class TrafficControl(object):
             ]
         )
 
-    def set_tc(self):
+    def set_shaping_rule(self):
         rule_finder = TcShapingRuleFinder(logger=logger, tc=self)
         if self.__is_change_shaping_rule and self.tc_command_output == TcCommandOutput.NOT_SET:
             if rule_finder.find_filter_param() is not None:
@@ -284,7 +287,7 @@ class TrafficControl(object):
 
         return self.__shaper.set_shaping()
 
-    def delete_all_tc(self):
+    def delete_all_rules(self):
         result_list = []
 
         result_list.append(self.__delete_qdisc())
@@ -300,7 +303,7 @@ class TrafficControl(object):
             try:
                 self.iptables_ctrl.clear()
             except OSError as e:
-                logger.warn("{} (can not delete iptables entries)".format(e))
+                logger.warning("{} (can not delete iptables entries)".format(e))
 
         return any(result_list)
 
@@ -341,7 +344,7 @@ class TrafficControl(object):
         rule_finder.clear()
         if not rule_finder.is_any_filter():
             logger.debug("there are no filters remain. delete qdiscs.")
-            self.delete_all_tc()
+            self.delete_all_rules()
 
         return result
 
@@ -374,7 +377,7 @@ class TrafficControl(object):
     def __get_device_qdisc_major_id(self):
         import hashlib
 
-        base_device_hash = hashlib.md5(six.b(self.device)).hexdigest()[:3]
+        base_device_hash = hashlib.md5(self.device.encode("latin-1")).hexdigest()[:3]
         device_hash_prefix = "1"
 
         return int(device_hash_prefix + base_device_hash, 16)
@@ -444,22 +447,27 @@ class TrafficControl(object):
         logging_msg = "delete {} qdisc".format(self.device)
 
         with logging_context(logging_msg):
-            runner = spr.SubprocessRunner(
+            returncode = run_command_helper(
                 "{:s} del dev {:s} root".format(
                     get_tc_base_command(TcSubCommand.QDISC), self.device
-                )
+                ),
+                ignore_error_msg_regexp=re.compile(
+                    "|".join(
+                        [
+                            "RTNETLINK answers: No such file or directory",  # Debian/Ubuntu
+                            "Error: Cannot delete qdisc with handle of zero",  # Debian 10
+                        ]
+                    )
+                ),
+                notice_msg="no qdisc to delete for the outgoing device.",
+                msg_log_level="INFO",
             )
-            runner.run()
-            if re.search("RTNETLINK answers: No such file or directory", runner.stderr):
-                logger.notice("no qdisc to delete for the outgoing device.")
-                return False
-            elif re.search("Cannot find device", runner.stderr):
-                raise NetworkInterfaceNotFoundError(target=self.device)
-            else:
-                is_success = runner.returncode == 0
-                if is_success:
-                    logger.info(logging_msg)
-                return is_success
+
+            is_success = returncode == 0
+            if is_success:
+                logger.info(logging_msg)
+
+            return is_success
 
     def __delete_ingress_qdisc(self):
         logging_msg = "delete {} ingress qdisc".format(self.device)
@@ -479,6 +487,7 @@ class TrafficControl(object):
                     )
                 ),
                 notice_msg="no qdisc to delete for the incoming device.",
+                msg_log_level="INFO",
             )
             is_success = returncode == 0
             if is_success:
@@ -487,18 +496,20 @@ class TrafficControl(object):
             return is_success
 
     def __delete_ifb_device(self):
-        from ._capabilities import has_execution_authority, get_permission_error_message
+        from ._capabilities import get_permission_error_message, has_execution_authority
 
         logging_msg = "delete {} ifb device ({})".format(self.device, self.ifb_device)
         with logging_context(logging_msg):
             verify_network_interface(self.ifb_device, self.__tc_command_output)
 
-            if not has_execution_authority("ip"):
-                logger.warn(get_permission_error_message("ip"))
+            if is_execute_tc_command(self.__tc_command_output) and not has_execution_authority(
+                "ip"
+            ):
+                logger.warning(get_permission_error_message("ip"))
 
                 return errno.EPERM
 
-            command_list = [
+            commands = [
                 "{:s} del dev {:s} root".format(
                     get_tc_base_command(TcSubCommand.QDISC), self.ifb_device
                 ),
@@ -506,9 +517,13 @@ class TrafficControl(object):
                 "{:s} link delete {:s} type ifb".format(find_bin_path("ip"), self.ifb_device),
             ]
 
-            if all([spr.SubprocessRunner(command).run() != 0 for command in command_list]):
+            if all([spr.SubprocessRunner(command).run() != 0 for command in commands]):
                 return 2
 
         logger.info(logging_msg)
 
         return 0
+
+
+def delete_all_rules(device):
+    TrafficControl(device).delete_all_rules()
