@@ -1,15 +1,14 @@
-# encoding: utf-8
-
 """
 .. codeauthor:: Tsuyoshi Hombashi <tsuyoshi.hombashi@gmail.com>
 """
 
+import humanreadable as hr
 import pytest
 
 from tcconfig._network import (
     _get_iproute2_upper_limite_rate,
     get_anywhere_network,
-    get_no_limit_kbits,
+    get_upper_limit_rate,
     is_anywhere_network,
     sanitize_network,
 )
@@ -20,7 +19,7 @@ def device_option(request):
     return request.config.getoption("--device")
 
 
-class Test_is_anywhere_network(object):
+class Test_is_anywhere_network:
     @pytest.mark.parametrize(
         ["network", "ip_version", "expected"],
         [
@@ -43,12 +42,12 @@ class Test_is_anywhere_network(object):
             is_anywhere_network(network, ip_version)
 
 
-class Test_get_iproute2_upper_limite_rate(object):
+class Test_get_iproute2_upper_limite_rate:
     def test_normal(self):
-        assert _get_iproute2_upper_limite_rate() == 32000000
+        assert _get_iproute2_upper_limite_rate() == hr.BitPerSecond("32Gbps")
 
 
-class Test_get_anywhere_network(object):
+class Test_get_anywhere_network:
     @pytest.mark.parametrize(
         ["value", "expected"], [[4, "0.0.0.0/0"], ["4", "0.0.0.0/0"], [6, "::/0"], ["6", "::/0"]]
     )
@@ -61,7 +60,7 @@ class Test_get_anywhere_network(object):
             get_anywhere_network(value)
 
 
-class Test_get_no_limit_kbits(object):
+class Test_get_upper_limit_rate:
     @pytest.mark.parametrize(["speed", "expected"], [[1, 1000], [0, 0]])
     def test_normal(self, monkeypatch, device_option, speed, expected):
         if device_option is None:
@@ -69,7 +68,7 @@ class Test_get_no_limit_kbits(object):
 
         monkeypatch.setattr("tcconfig._network._read_iface_speed", lambda x: speed)
 
-        assert get_no_limit_kbits(device_option) == expected
+        assert get_upper_limit_rate(device_option).kilo_bps == expected
 
     @pytest.mark.parametrize(["speed", "expected"], [[-1, _get_iproute2_upper_limite_rate()]])
     def test_normal_paravirt(self, monkeypatch, device_option, speed, expected):
@@ -78,11 +77,11 @@ class Test_get_no_limit_kbits(object):
 
         monkeypatch.setattr("tcconfig._network._read_iface_speed", lambda x: speed)
 
-        assert get_no_limit_kbits(device_option) == expected
+        assert get_upper_limit_rate(device_option) == expected
 
     @staticmethod
     def raise_ioerror(tc_device):
-        raise IOError()
+        raise OSError()
 
     def test_exception(self, monkeypatch, device_option):
         if device_option is None:
@@ -90,10 +89,10 @@ class Test_get_no_limit_kbits(object):
 
         monkeypatch.setattr("tcconfig._network._read_iface_speed", self.raise_ioerror)
 
-        assert get_no_limit_kbits(device_option) == _get_iproute2_upper_limite_rate()
+        assert get_upper_limit_rate(device_option) == _get_iproute2_upper_limite_rate()
 
 
-class Test_sanitize_network(object):
+class Test_sanitize_network:
     @pytest.mark.parametrize(
         ["value", "ip_version", "expected"],
         [
